@@ -221,6 +221,10 @@
         loadUrl: function (url, $target, data, method, action, autorefresh, progressTimer, extraHeaders) {
             var id = null;
 
+            if (url.startsWith('//') || ! url.startsWith(this.baseUrl + '/')) {
+                throw new Error('URL ' + url + ' is not relative to ' + this.baseUrl);
+            }
+
             // Default method is GET
             if ('undefined' === typeof method) {
                 method = 'GET';
@@ -456,21 +460,6 @@
             return true;
         },
 
-        /**
-         * Add the specified flag to the given URL
-         *
-         * @param {string} url
-         * @param {string} flag
-         *
-         * @returns {string}
-         *
-         * @deprecated since version 2.8.0. Use {@link Icinga.Utils.addUrlFlag()} instead
-         */
-        addUrlFlag: function(url, flag)
-        {
-            return this.icinga.utils.addUrlFlag(url, flag);
-        },
-
         /**
          * Process the X-Icinga-Redirect HTTP Response Header
          *
@@ -734,7 +723,6 @@
                 announceReq.scripted = true;
             }
 
-            var rendered = false;
             var classes;
 
             if (target !== 'layout') {
@@ -784,35 +772,6 @@
                 this.icinga.ui.setWindowId(windowId);
             }
 
-            // Handle search requests, still hardcoded.
-            if (req.url.match(/^\/search/) && req.$target.data('icingaUrl').match(/^\/search/)) {
-                var $resp = $('<div>' + req.responseText + '</div>'); // div helps getting an XML tree
-                if ($('.dashboard', $resp).length > 0 && $('.dashboard .container', req.$target).length > 0) {
-                    // TODO: We need dashboard pane and container identifiers (not ids)
-                    var targets = [];
-                    $('.dashboard .container', req.$target).each(function (idx, el) {
-                        targets.push($(el));
-                    });
-
-                    var i = 0;
-                    // Searching for '.dashboard .container' in $resp doesn't dork?!
-                    $('.dashboard .container', $resp).each(function (idx, el) {
-                        var $el = $(el);
-                        if ($el.hasClass('dashboard')) {
-                            return;
-                        }
-                        var url = $el.data('icingaUrl');
-                        targets[i].data('icingaUrl', url);
-                        var title = $('h1', $el).first();
-                        $('h1', targets[i]).first().replaceWith(title);
-
-                        _this.loadUrl(url, targets[i]);
-                        i++;
-                    });
-                    rendered = true;
-                }
-            }
-
             var referrer = req.referrer;
             if (typeof referrer === 'undefined') {
                 referrer = req;
@@ -829,10 +788,6 @@
 
             req.$target.data('icingaUrl', req.url);
 
-            if (rendered) {
-                return;
-            }
-
             if (typeof req.progressTimer !== 'undefined') {
                 this.icinga.timer.unregister(req.progressTimer);
             }
